---
title: <span class="badge object-type-scalar"></span> Bictoin
---
# <span class="badge object-type-scalar"></span> Bictoin

Currency: Bitcoin (฿)

## Definition

```python
# Currency: Bitcoin (฿)
Bictoin: typing.Literal["currencyBTC"] = "currencyBTC"
```
